#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-chans
version:              3.0.0.4
visibility:           public
id:                   stm-chans-3.0.0.4-KHX93OdHq4J7gERqC9jfvv
key:                  stm-chans-3.0.0.4-KHX93OdHq4J7gERqC9jfvv
license:              BSD-3-Clause
copyright:            Copyright (c) 2011--2015 wren gayle romano
maintainer:           wren@community.haskell.org
author:               wren gayle romano, Thomas DuBuisson
stability:            provisional
homepage:             http://code.haskell.org/~wren/
synopsis:             Additional types of channels for STM.
description:          Additional types of channels for STM.
category:             Concurrency
abi:                  c2b63339d9f16820d4efdeb937b9b583
exposed:              True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue

import-dirs:          /usr/lib/ghc-8.10.5/site-local/stm-chans-3.0.0.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/stm-chans-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/stm-chans-3.0.0.4
hs-libraries:         HSstm-chans-3.0.0.4-KHX93OdHq4J7gERqC9jfvv
depends:              base-4.14.2.0 stm-2.5.0.1
haddock-interfaces:   /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html:         /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

